@@ -16,20 +16,17 @@
 """Usage action implementations"""
 
 import datetime
-import logging
 import sys
 
-from cliff import lister
-from cliff import show
+from osc_lib.command import command
+from osc_lib import utils
 import six
 
-from openstackclient.common import utils
+from openstackclient.i18n import _
 
 
-class ListUsage(lister.Lister):
-    """List resource usage per project"""
-
-    log = logging.getLogger(__name__ + ".ListUsage")
+class ListUsage(command.Lister):
+    _description = _("List resource usage per project")
 
     def get_parser(self, prog_name):
         parser = super(ListUsage, self).get_parser(prog_name)
@@ -37,19 +34,18 @@ class ListUsage(lister.Lister):
             "--start",
             metavar="<start>",
             default=None,
-            help="Usage range start date, ex 2012-01-20"
-                 " (default: 4 weeks ago)"
+            help=_("Usage range start date, ex 2012-01-20"
+                   " (default: 4 weeks ago)")
         )
         parser.add_argument(
             "--end",
             metavar="<end>",
             default=None,
-            help="Usage range end date, ex 2012-01-20 (default: tomorrow)"
+            help=_("Usage range end date, ex 2012-01-20 (default: tomorrow)")
         )
         return parser
 
     def take_action(self, parsed_args):
-        self.log.debug("take_action(%s)", parsed_args)
 
         def _format_project(project):
             if not project:
@@ -93,17 +89,17 @@ class ListUsage(lister.Lister):
         # Cache the project list
         project_cache = {}
         try:
-            for p in self.app.client_manager.identity.tenants.list():
+            for p in self.app.client_manager.identity.projects.list():
                 project_cache[p.id] = p
         except Exception:
             # Just forget it if there's any trouble
             pass
 
         if parsed_args.formatter == 'table' and len(usage_list) > 0:
-            sys.stdout.write("Usage from %s to %s: \n" % (
-                start.strftime(dateformat),
-                end.strftime(dateformat),
-            ))
+            sys.stdout.write(_("Usage from %(start)s to %(end)s: \n") % {
+                "start": start.strftime(dateformat),
+                "end": end.strftime(dateformat),
+            })
 
         return (column_headers,
                 (utils.get_item_properties(
@@ -118,10 +114,8 @@ class ListUsage(lister.Lister):
                 ) for s in usage_list))
 
 
-class ShowUsage(show.ShowOne):
-    """Show resource usage for a single project"""
-
-    log = logging.getLogger(__name__ + ".ShowUsage")
+class ShowUsage(command.ShowOne):
+    _description = _("Show resource usage for a single project")
 
     def get_parser(self, prog_name):
         parser = super(ShowUsage, self).get_parser(prog_name)
@@ -129,26 +123,24 @@ class ShowUsage(show.ShowOne):
             "--project",
             metavar="<project>",
             default=None,
-            help="Name or ID of project to show usage for"
+            help=_("Name or ID of project to show usage for")
         )
         parser.add_argument(
             "--start",
             metavar="<start>",
             default=None,
-            help="Usage range start date, ex 2012-01-20"
-                 " (default: 4 weeks ago)"
+            help=_("Usage range start date, ex 2012-01-20"
+                   " (default: 4 weeks ago)")
         )
         parser.add_argument(
             "--end",
             metavar="<end>",
             default=None,
-            help="Usage range end date, ex 2012-01-20 (default: tomorrow)"
+            help=_("Usage range end date, ex 2012-01-20 (default: tomorrow)")
         )
         return parser
 
     def take_action(self, parsed_args):
-        self.log.debug("take_action(%s)", parsed_args)
-
         identity_client = self.app.client_manager.identity
         compute_client = self.app.client_manager.compute
         dateformat = "%Y-%m-%d"
@@ -176,11 +168,12 @@ class ShowUsage(show.ShowOne):
         usage = compute_client.usage.get(project, start, end)
 
         if parsed_args.formatter == 'table':
-            sys.stdout.write("Usage from %s to %s on project %s: \n" % (
-                start.strftime(dateformat),
-                end.strftime(dateformat),
-                project
-            ))
+            sys.stdout.write(_("Usage from %(start)s to %(end)s on "
+                               "project %(project)s: \n") % {
+                "start": start.strftime(dateformat),
+                "end": end.strftime(dateformat),
+                "project": project,
+            })
 
         info = {}
         info['Servers'] = (
@@ -196,20 +189,3 @@ class ShowUsage(show.ShowOne):
             float("%.2f" % usage.total_local_gb_usage)
             if hasattr(usage, "total_local_gb_usage") else None)
         return zip(*sorted(six.iteritems(info)))
-
-
-# This is out of order due to the subclass, will eventually be removed
-
-class ListProjectUsage(ListUsage):
-    """List resource usage per project"""
-
-    deprecated = True
-
-    log = logging.getLogger('DEPRECATED:')
-
-    def take_action(self, parsed_args):
-        self.log.warning(
-            "%s is deprecated, use 'usage list'",
-            getattr(self, 'cmd_name', 'this command'),
-        )
-        return super(ListProjectUsage, self).take_action(parsed_args)
