@@ -128,12 +128,13 @@ class CreateImage(command.ShowOne):
             metavar="<image-url>",
             help=_("Copy image from the data store (similar to --location)"),
         )
-        parser.add_argument(
+        source_group = parser.add_mutually_exclusive_group()
+        source_group.add_argument(
             "--file",
             metavar="<file>",
             help=_("Upload image from local file"),
         )
-        parser.add_argument(
+        source_group.add_argument(
             "--volume",
             metavar="<volume>",
             help=_("Create image from a volume"),
@@ -624,11 +625,11 @@ class SetImage(command.Command):
         kwargs = {}
         copy_attrs = ('name', 'owner', 'min_disk', 'min_ram', 'properties',
                       'container_format', 'disk_format', 'size', 'store',
-                      'location', 'copy_from', 'volume', 'force', 'checksum')
+                      'location', 'copy_from', 'volume', 'checksum')
         for attr in copy_attrs:
             if attr in parsed_args:
                 val = getattr(parsed_args, attr, None)
-                if val:
+                if val is not None:
                     # Only include a value in kwargs for attributes that are
                     # actually present on the command line
                     kwargs[attr] = val
@@ -652,6 +653,8 @@ class SetImage(command.Command):
             kwargs['is_public'] = True
         if parsed_args.private:
             kwargs['is_public'] = False
+        if parsed_args.force:
+            kwargs['force'] = True
 
         # Wrap the call to catch exceptions in order to close files
         try:
@@ -712,6 +715,12 @@ class ShowImage(command.ShowOne):
 
     def get_parser(self, prog_name):
         parser = super(ShowImage, self).get_parser(prog_name)
+        parser.add_argument(
+            "--human-readable",
+            default=False,
+            action='store_true',
+            help=_("Print image size in a human-friendly format."),
+        )
         parser.add_argument(
             "image",
             metavar="<image>",
@@ -728,5 +737,8 @@ class ShowImage(command.ShowOne):
 
         info = {}
         info.update(image._info)
+        if parsed_args.human_readable:
+            if 'size' in info:
+                info['size'] = utils.format_size(info['size'])
         info['properties'] = utils.format_dict(info.get('properties', {}))
         return zip(*sorted(six.iteritems(info)))
