@@ -302,7 +302,8 @@ class CreatePort(command.ShowOne):
             help=_("Network this port belongs to (name or ID)")
         )
         _add_updatable_args(parser)
-        parser.add_argument(
+        fixed_ip = parser.add_mutually_exclusive_group()
+        fixed_ip.add_argument(
             '--fixed-ip',
             metavar='subnet=<subnet>,ip-address=<ip-address>',
             action=parseractions.MultiKeyValueAction,
@@ -311,6 +312,11 @@ class CreatePort(command.ShowOne):
                    "subnet=<subnet>,ip-address=<ip-address> "
                    "(repeat option to set multiple fixed IP addresses)")
         )
+        fixed_ip.add_argument(
+            '--no-fixed-ip',
+            action='store_true',
+            help=_("No IP or subnet for this port.")
+        )
         parser.add_argument(
             '--binding-profile',
             metavar='<binding-profile>',
@@ -402,6 +408,8 @@ class CreatePort(command.ShowOne):
 
         if parsed_args.fixed_ip:
             attrs['fixed_ips'] = parsed_args.fixed_ip
+        elif parsed_args.no_fixed_ip:
+            attrs['fixed_ips'] = []
 
         if parsed_args.security_group:
             attrs['security_group_ids'] = [client.find_security_group(
@@ -491,6 +499,11 @@ class ListPort(command.Lister):
             metavar='<server>',
             help=_("List only ports attached to this server (name or ID)"),
         )
+        device_group.add_argument(
+            '--device-id',
+            metavar='<device-id>',
+            help=_("List only ports with the specified device ID")
+        )
         parser.add_argument(
             '--mac-address',
             metavar='<mac-address>',
@@ -545,6 +558,8 @@ class ListPort(command.Lister):
             column_headers += ('Security Groups', 'Device Owner', 'Tags')
         if parsed_args.device_owner is not None:
             filters['device_owner'] = parsed_args.device_owner
+        if parsed_args.device_id is not None:
+            filters['device_id'] = parsed_args.device_id
         if parsed_args.router:
             _router = network_client.find_router(parsed_args.router,
                                                  ignore_missing=False)
@@ -576,9 +591,11 @@ class ListPort(command.Lister):
 
         data = network_client.ports(**filters)
 
-        return (column_headers,
+        headers, attrs = utils.calculate_header_and_attrs(
+            column_headers, columns, parsed_args)
+        return (headers,
                 (utils.get_item_properties(
-                    s, columns,
+                    s, attrs,
                     formatters=_formatters,
                 ) for s in data))
 
