@@ -26,6 +26,7 @@ from osc_lib import utils
 from openstackclient.i18n import _
 from openstackclient.identity import common as identity_common
 from openstackclient.network import sdk_utils
+from openstackclient.network.v2 import _tag
 
 
 LOG = logging.getLogger(__name__)
@@ -35,7 +36,7 @@ def _format_admin_state(state):
     return 'UP' if state else 'DOWN'
 
 
-def _format_external_gateway_info(info):
+def _format_router_info(info):
     try:
         return json.dumps(info)
     except (TypeError, KeyError):
@@ -53,10 +54,11 @@ def _format_routes(routes):
 _formatters = {
     'admin_state_up': _format_admin_state,
     'is_admin_state_up': _format_admin_state,
-    'external_gateway_info': _format_external_gateway_info,
+    'external_gateway_info': _format_router_info,
     'availability_zones': utils.format_list,
     'availability_zone_hints': utils.format_list,
     'routes': _format_routes,
+    'tags': utils.format_list,
 }
 
 
@@ -67,6 +69,8 @@ def _get_columns(item):
         'is_distributed': 'distributed',
         'is_admin_state_up': 'admin_state_up',
     }
+    if hasattr(item, 'interfaces_info'):
+        column_map['interfaces_info'] = 'interfaces_info'
     return sdk_utils.get_osc_show_columns_for_sdk_resource(item, column_map)
 
 
@@ -78,8 +82,7 @@ def _get_attrs(client_manager, parsed_args):
         attrs['admin_state_up'] = True
     if parsed_args.disable:
         attrs['admin_state_up'] = False
-    # centralized is available only for SetRouter and not for CreateRouter
-    if 'centralized' in parsed_args and parsed_args.centralized:
+    if parsed_args.centralized:
         attrs['distributed'] = False
     if parsed_args.distributed:
         attrs['distributed'] = True
@@ -176,18 +179,28 @@ class CreateRouter(command.ShowOne):
             action='store_true',
             help=_("Disable router")
         )
-        parser.add_argument(
+        distribute_group = parser.add_mutually_exclusive_group()
+        distribute_group.add_argument(
             '--distributed',
-            dest='distributed',
             action='store_true',
-            default=False,
             help=_("Create a distributed router")
         )
-        parser.add_argument(
+        distribute_group.add_argument(
+            '--centralized',
+            action='store_true',
+            help=_("Create a centralized router")
+        )
+        ha_group = parser.add_mutually_exclusive_group()
+        ha_group.add_argument(
             '--ha',
             action='store_true',
             help=_("Create a highly available router")
         )
+        ha_group.add_argument(
+            '--no-ha',
+            action='store_true',
+            help=_("Create a legacy router")
+        )
         parser.add_argument(
             '--description',
             metavar='<description>',
@@ -208,6 +221,7 @@ class CreateRouter(command.ShowOne):
                    "(Router Availability Zone extension required, "
                    "repeat option to set multiple availability zones)")
         )
+        _tag.add_tag_option_to_parser_for_create(parser, _('router'))
 
         return parser
 
@@ -216,8 +230,12 @@ class CreateRouter(command.ShowOne):
 
         attrs = _get_attrs(self.app.client_manager, parsed_args)
         if parsed_args.ha:
-            attrs['ha'] = parsed_args.ha
+            attrs['ha'] = True
+        if parsed_args.no_ha:
+            attrs['ha'] = False
         obj = client.create_router(**attrs)
+        # tags cannot be set when created, so tags need to be set later.
+        _tag.update_tags_for_set(client, obj, parsed_args)
 
         display_columns, columns = _get_columns(obj)
         data = utils.get_item_properties(obj, columns, formatters=_formatters)
@@ -249,8 +267,8 @@ class DeleteRouter(command.Command):
             except Exception as e:
                 result += 1
                 LOG.error(_("Failed to delete router with "
-                          "name or ID '%(router)s': %(e)s")
-                          % {'router': router, 'e': e})
+                          "name or ID '%(router)s': %(e)s"),
+                          {'router': router, 'e': e})
 
         if result > 0:
             total = len(parsed_args.router)
@@ -294,11 +312,19 @@ class ListRouter(command.Lister):
             help=_("List routers according to their project (name or ID)")
         )
         identity_common.add_project_domain_option_to_parser(parser)
+        parser.add_argument(
+            '--agent',
+            metavar='<agent-id>',
+            help=_("List routers hosted by an agent (ID only)")
+        )
+        _tag.add_tag_filtering_option_to_parser(parser, _('routers'))
+
         return parser
 
     def take_action(self, parsed_args):
         identity_client = self.app.client_manager.identity
         client = self.app.client_manager.network
+
         columns = (
             'id',
             'name',
@@ -338,6 +364,18 @@ class ListRouter(command.Lister):
             ).id
             args['tenant_id'] = project_id
             args['project_id'] = project_id
+
+        _tag.get_tag_filtering_args(parsed_args, args)
+
+        if parsed_args.agent is not None:
+            agent = client.get_agent(parsed_args.agent)
+            data = client.agent_hosted_routers(agent)
+            # NOTE: Networking API does not support filtering by parameters,
+            # so we need filtering in the client side.
+            data = [d for d in data if self._filter_match(d, args)]
+        else:
+            data = client.routers(**args)
+
         if parsed_args.long:
             columns = columns + (
                 'routes',
@@ -356,14 +394,29 @@ class ListRouter(command.Lister):
                 column_headers = column_headers + (
                     'Availability zones',
                 )
+            columns = columns + ('tags',)
+            column_headers = column_headers + ('Tags',)
 
-        data = client.routers(**args)
         return (column_headers,
                 (utils.get_item_properties(
                     s, columns,
                     formatters=_formatters,
                 ) for s in data))
 
+    @staticmethod
+    def _filter_match(data, conditions):
+        for key, value in conditions.items():
+            try:
+                if getattr(data, key) != value:
+                    return False
+            except AttributeError:
+                # Some filter attributes like tenant_id or admin_state_up
+                # are backward compatibility in older OpenStack SDK support.
+                # They does not exist in the latest release.
+                # In this case we just skip checking such filter condition.
+                continue
+        return True
+
 
 class RemovePortFromRouter(command.Command):
     _description = _("Remove a port from a router")
@@ -526,6 +579,7 @@ class SetRouter(command.Command):
             action='store_true',
             help=_("Disable Source NAT on external gateway")
         )
+        _tag.add_tag_option_to_parser_for_set(parser, _('router'))
         return parser
 
     def take_action(self, parsed_args):
@@ -584,7 +638,10 @@ class SetRouter(command.Command):
                     ips.append(ip_spec)
                 gateway_info['external_fixed_ips'] = ips
             attrs['external_gateway_info'] = gateway_info
-        client.update_router(obj, **attrs)
+        if attrs:
+            client.update_router(obj, **attrs)
+        # tags is a subresource and it needs to be updated separately.
+        _tag.update_tags_for_set(client, obj, parsed_args)
 
 
 class ShowRouter(command.ShowOne):
@@ -602,7 +659,22 @@ class ShowRouter(command.ShowOne):
     def take_action(self, parsed_args):
         client = self.app.client_manager.network
         obj = client.find_router(parsed_args.router, ignore_missing=False)
+        interfaces_info = []
+        filters = {}
+        filters['device_id'] = obj.id
+        for port in client.ports(**filters):
+            if port.device_owner != "network:router_gateway":
+                for ip_spec in port.fixed_ips:
+                    int_info = {
+                        'port_id': port.id,
+                        'ip_address': ip_spec.get('ip_address'),
+                        'subnet_id': ip_spec.get('subnet_id')
+                    }
+                    interfaces_info.append(int_info)
+
+        setattr(obj, 'interfaces_info', interfaces_info)
         display_columns, columns = _get_columns(obj)
+        _formatters['interfaces_info'] = _format_router_info
         data = utils.get_item_properties(obj, columns, formatters=_formatters)
 
         return (display_columns, data)
@@ -634,6 +706,7 @@ class UnsetRouter(command.Command):
             metavar="<router>",
             help=_("Router to modify (name or ID)")
         )
+        _tag.add_tag_option_to_parser_for_unset(parser, _('router'))
         return parser
 
     def take_action(self, parsed_args):
@@ -654,3 +727,5 @@ class UnsetRouter(command.Command):
             attrs['external_gateway_info'] = {}
         if attrs:
             client.update_router(obj, **attrs)
+        # tags is a subresource and it needs to be updated separately.
+        _tag.update_tags_for_unset(client, obj, parsed_args)
