@@ -15,16 +15,21 @@
 
 """Container v1 action implementations"""
 
+import logging
 
+from osc_lib.cli import parseractions
+from osc_lib.command import command
+from osc_lib import utils
 import six
 
-from openstackclient.common import command
-from openstackclient.common import parseractions
-from openstackclient.common import utils
+from openstackclient.i18n import _
+
+
+LOG = logging.getLogger(__name__)
 
 
 class CreateContainer(command.Lister):
-    """Create new container"""
+    _description = _("Create new container")
 
     def get_parser(self, prog_name):
         parser = super(CreateContainer, self).get_parser(prog_name)
@@ -32,7 +37,7 @@ class CreateContainer(command.Lister):
             'containers',
             metavar='<container-name>',
             nargs="+",
-            help='New container name(s)',
+            help=_('New container name(s)'),
         )
         return parser
 
@@ -40,6 +45,10 @@ class CreateContainer(command.Lister):
 
         results = []
         for container in parsed_args.containers:
+            if len(container) > 256:
+                LOG.warning(
+                    _('Container name is %s characters long, the default limit'
+                      ' is 256'), len(container))
             data = self.app.client_manager.object_store.container_create(
                 container=container,
             )
@@ -54,7 +63,7 @@ class CreateContainer(command.Lister):
 
 
 class DeleteContainer(command.Command):
-    """Delete container"""
+    _description = _("Delete container")
 
     def get_parser(self, prog_name):
         parser = super(DeleteContainer, self).get_parser(prog_name)
@@ -62,13 +71,13 @@ class DeleteContainer(command.Command):
             '--recursive', '-r',
             action='store_true',
             default=False,
-            help='Recursively delete objects and container',
+            help=_('Recursively delete objects and container'),
         )
         parser.add_argument(
             'containers',
             metavar='<container>',
             nargs="+",
-            help='Container(s) to delete',
+            help=_('Container(s) to delete'),
         )
         return parser
 
@@ -89,42 +98,42 @@ class DeleteContainer(command.Command):
 
 
 class ListContainer(command.Lister):
-    """List containers"""
+    _description = _("List containers")
 
     def get_parser(self, prog_name):
         parser = super(ListContainer, self).get_parser(prog_name)
         parser.add_argument(
             "--prefix",
             metavar="<prefix>",
-            help="Filter list using <prefix>",
+            help=_("Filter list using <prefix>"),
         )
         parser.add_argument(
             "--marker",
             metavar="<marker>",
-            help="Anchor for paging",
+            help=_("Anchor for paging"),
         )
         parser.add_argument(
             "--end-marker",
             metavar="<end-marker>",
-            help="End anchor for paging",
+            help=_("End anchor for paging"),
         )
         parser.add_argument(
             "--limit",
-            metavar="<limit>",
+            metavar="<num-containers>",
             type=int,
-            help="Limit the number of containers returned",
+            help=_("Limit the number of containers returned"),
         )
         parser.add_argument(
             '--long',
             action='store_true',
             default=False,
-            help='List additional fields in output',
+            help=_('List additional fields in output'),
         )
         parser.add_argument(
             '--all',
             action='store_true',
             default=False,
-            help='List all containers (default is 10000)',
+            help=_('List all containers (default is 10000)'),
         )
         return parser
 
@@ -159,14 +168,14 @@ class ListContainer(command.Lister):
 
 
 class SaveContainer(command.Command):
-    """Save container contents locally"""
+    _description = _("Save container contents locally")
 
     def get_parser(self, prog_name):
         parser = super(SaveContainer, self).get_parser(prog_name)
         parser.add_argument(
             'container',
             metavar='<container>',
-            help='Container to save',
+            help=_('Container to save'),
         )
         return parser
 
@@ -177,22 +186,22 @@ class SaveContainer(command.Command):
 
 
 class SetContainer(command.Command):
-    """Set container properties"""
+    _description = _("Set container properties")
 
     def get_parser(self, prog_name):
         parser = super(SetContainer, self).get_parser(prog_name)
         parser.add_argument(
             'container',
             metavar='<container>',
-            help='Container to modify',
+            help=_('Container to modify'),
         )
         parser.add_argument(
             "--property",
             metavar="<key=value>",
             required=True,
             action=parseractions.KeyValueAction,
-            help="Set a property on this container "
-                 "(repeat option to set multiple properties)"
+            help=_("Set a property on this container "
+                   "(repeat option to set multiple properties)")
         )
         return parser
 
@@ -204,14 +213,14 @@ class SetContainer(command.Command):
 
 
 class ShowContainer(command.ShowOne):
-    """Display container details"""
+    _description = _("Display container details")
 
     def get_parser(self, prog_name):
         parser = super(ShowContainer, self).get_parser(prog_name)
         parser.add_argument(
             'container',
             metavar='<container>',
-            help='Container to display',
+            help=_('Container to display'),
         )
         return parser
 
@@ -227,14 +236,14 @@ class ShowContainer(command.ShowOne):
 
 
 class UnsetContainer(command.Command):
-    """Unset container properties"""
+    _description = _("Unset container properties")
 
     def get_parser(self, prog_name):
         parser = super(UnsetContainer, self).get_parser(prog_name)
         parser.add_argument(
             'container',
             metavar='<container>',
-            help='Container to modify',
+            help=_('Container to modify'),
         )
         parser.add_argument(
             '--property',
@@ -242,8 +251,8 @@ class UnsetContainer(command.Command):
             required=True,
             action='append',
             default=[],
-            help='Property to remove from container '
-                 '(repeat option to remove multiple properties)',
+            help=_('Property to remove from container '
+                   '(repeat option to remove multiple properties)'),
         )
         return parser
 
